# Scrape YouTube comments

```scraper_yt``` is a package which allows the user to scrape comments off of YouTube videos with ease.

- Free software: MIT license

## Installation

```pip install scraper_yt``` 

## Changelog

#### 0.1.0 (2020-11-18)

- First release on PyPI.
